@@ -31,6 +31,7 @@
 #include <libempathy/empathy-contact.h>
 
 #include "empathy-contact-list-store.h"
+#include "empathy-contact-menu.h"
 
 G_BEGIN_DECLS
 
@@ -49,38 +50,29 @@ typedef enum {
 	EMPATHY_CONTACT_LIST_FEATURE_GROUPS_SAVE = 1 << 0,
 	EMPATHY_CONTACT_LIST_FEATURE_GROUPS_RENAME = 1 << 1,
 	EMPATHY_CONTACT_LIST_FEATURE_GROUPS_REMOVE = 1 << 2,
-	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_CHAT = 1 << 3,
-	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_CALL = 1 << 4,
-	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_LOG = 1 << 5,
-	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_FT = 1 << 6,
-	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_INVITE = 1 << 7,
-	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_EDIT = 1 << 8,
-	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_INFO = 1 << 9,
-	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_REMOVE = 1 << 10,
-	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_DROP = 1 << 11,
-	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_DRAG = 1 << 12,
-	EMPATHY_CONTACT_LIST_FEATURE_ALL = (1 << 13) - 1,
-} EmpathyContactListFeatures;
+	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_REMOVE = 1 << 3,
+	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_DROP = 1 << 4,
+	EMPATHY_CONTACT_LIST_FEATURE_CONTACT_DRAG = 1 << 5,
+	EMPATHY_CONTACT_LIST_FEATURE_ALL = (1 << 6) - 1,
+} EmpathyContactListFeatureFlags;
 
 struct _EmpathyContactListView {
-	GtkTreeView            parent;
+	GtkTreeView parent;
+	gpointer priv;
 };
 
 struct _EmpathyContactListViewClass {
-	GtkTreeViewClass       parent_class;
+	GtkTreeViewClass parent_class;
 };
 
 GType                      empathy_contact_list_view_get_type           (void) G_GNUC_CONST;
-EmpathyContactListView *   empathy_contact_list_view_new                (EmpathyContactListStore    *store,
-								         EmpathyContactListFeatures  features);
-void                       empathy_contact_list_view_set_features       (EmpathyContactListView     *view,
-								         EmpathyContactListFeatures  features);
-EmpathyContactListFeatures empathy_contact_list_view_get_features       (EmpathyContactListView     *view);
-EmpathyContact *           empathy_contact_list_view_get_selected       (EmpathyContactListView     *view);
-gchar *                    empathy_contact_list_view_get_selected_group (EmpathyContactListView     *view);
-GtkWidget *                empathy_contact_list_view_get_contact_menu   (EmpathyContactListView     *view,
-								         EmpathyContact             *contact);
-GtkWidget *                empathy_contact_list_view_get_group_menu     (EmpathyContactListView     *view);
+EmpathyContactListView *   empathy_contact_list_view_new                (EmpathyContactListStore        *store,
+								         EmpathyContactListFeatureFlags  list_features,
+								         EmpathyContactFeatureFlags      contact_features);
+EmpathyContact *           empathy_contact_list_view_get_selected       (EmpathyContactListView         *view);
+gchar *                    empathy_contact_list_view_get_selected_group (EmpathyContactListView         *view);
+GtkWidget *                empathy_contact_list_view_get_contact_menu   (EmpathyContactListView         *view);
+GtkWidget *                empathy_contact_list_view_get_group_menu     (EmpathyContactListView         *view);
 
 G_END_DECLS
 
