@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2007 Collabora Ltd.
+ * Copyright (C) 2007-2008 Collabora Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,7 +31,7 @@
 #include <libmissioncontrol/mc-account.h>
 #include <libmissioncontrol/mission-control.h>
 
-#include <libempathy/empathy-debug.h>
+#include <libempathy/empathy-contact-factory.h>
 #include <libempathy/empathy-utils.h>
 
 #include <libempathy-gtk/empathy-ui-utils.h>
@@ -39,43 +39,58 @@
 #include "empathy-new-message-dialog.h"
 #include "empathy-account-chooser.h"
 
-#define DEBUG_DOMAIN "NewMessageDialog"
-
 typedef struct {
 	GtkWidget *dialog;
 	GtkWidget *table_contact;
 	GtkWidget *account_chooser;
 	GtkWidget *entry_id;
+	GtkWidget *button_chat;
+	GtkWidget *button_call;
 } EmpathyNewMessageDialog;
 
-
 static void
 new_message_dialog_response_cb (GtkWidget               *widget,
-				gint                     response,
+				gint                    response,
 				EmpathyNewMessageDialog *dialog)
 {
-	if (response == GTK_RESPONSE_OK) {
-		MissionControl *mc;
-		McAccount      *account;
-		const gchar    *id;
+	McAccount   *account;
+	const gchar *id;
 
-		account = empathy_account_chooser_get_account (EMPATHY_ACCOUNT_CHOOSER (dialog->account_chooser));
-		id = gtk_entry_get_text (GTK_ENTRY (dialog->entry_id));
-		mc = empathy_mission_control_new ();
-
-		mission_control_request_channel_with_string_handle (mc,
-								    account,
-								    TP_IFACE_CHANNEL_TYPE_TEXT,
-								    id,
-								    TP_HANDLE_TYPE_CONTACT,
-								    NULL, NULL);
-		g_object_unref (mc);
-		g_object_unref (account);
+	account = empathy_account_chooser_get_account (EMPATHY_ACCOUNT_CHOOSER (dialog->account_chooser));
+	id = gtk_entry_get_text (GTK_ENTRY (dialog->entry_id));
+	if (!account || G_STR_EMPTY (id)) {
+		if (account) {
+			g_object_unref (account);
+		}
+		gtk_widget_destroy (widget);
+		return;
 	}
 
+	if (response == 1) {
+		empathy_call_with_contact_id (account, id);
+	}	
+	else if (response == 2) {
+		empathy_chat_with_contact_id (account, id);
+	}
+
+	g_object_unref (account);
 	gtk_widget_destroy (widget);
 }
 
+static void
+new_message_change_state_button_cb  (GtkEditable             *editable,
+				     EmpathyNewMessageDialog *dialog)  
+{
+	const gchar *id;
+	gboolean     sensitive;
+
+	id = gtk_entry_get_text (GTK_ENTRY (editable));
+	sensitive = !G_STR_EMPTY (id);
+	
+	gtk_widget_set_sensitive (dialog->button_chat, sensitive);
+	gtk_widget_set_sensitive (dialog->button_call, sensitive);
+}
+
 static void
 new_message_dialog_destroy_cb (GtkWidget               *widget,
 			       EmpathyNewMessageDialog *dialog)
@@ -88,6 +103,7 @@ empathy_new_message_dialog_show (GtkWindow *parent)
 {
 	static EmpathyNewMessageDialog *dialog = NULL;
 	GladeXML                       *glade;
+	gchar                          *filename;
 
 	if (dialog) {
 		gtk_window_present (GTK_WINDOW (dialog->dialog));
@@ -96,19 +112,25 @@ empathy_new_message_dialog_show (GtkWindow *parent)
 
 	dialog = g_new0 (EmpathyNewMessageDialog, 1);
 
-	glade = empathy_glade_get_file ("empathy-new-message-dialog.glade",
-				       "new_message_dialog",
-				       NULL,
-				       "new_message_dialog", &dialog->dialog,
-				       "table_contact", &dialog->table_contact,
-				       "entry_id", &dialog->entry_id,
-				       NULL);
+	filename = empathy_file_lookup ("empathy-new-message-dialog.glade",
+					"libempathy-gtk");
+	glade = empathy_glade_get_file (filename,
+				        "new_message_dialog",
+				        NULL,
+				        "new_message_dialog", &dialog->dialog,
+				        "table_contact", &dialog->table_contact,
+				        "entry_id", &dialog->entry_id,
+					"button_chat", &dialog->button_chat,
+					"button_call",&dialog->button_call,
+				        NULL);
+	g_free (filename);
 
 	empathy_glade_connect (glade,
-			      dialog,
-			      "new_message_dialog", "destroy", new_message_dialog_destroy_cb,
-			      "new_message_dialog", "response", new_message_dialog_response_cb,
-			      NULL);
+			       dialog,
+			       "new_message_dialog", "destroy", new_message_dialog_destroy_cb,
+			       "new_message_dialog", "response", new_message_dialog_response_cb,
+			       "entry_id", "changed", new_message_change_state_button_cb,
+			       NULL);
 
 	g_object_add_weak_pointer (G_OBJECT (dialog->dialog), (gpointer) &dialog);
 
@@ -129,6 +151,9 @@ empathy_new_message_dialog_show (GtkWindow *parent)
 					      GTK_WINDOW (parent));
 	}
 
+	gtk_widget_set_sensitive (dialog->button_chat, FALSE);
+	gtk_widget_set_sensitive (dialog->button_call, FALSE);
+
 	gtk_widget_show (dialog->dialog);
 
 	return dialog->dialog;
