@@ -31,13 +31,10 @@
 #include "empathy-log-manager.h"
 #include "empathy-contact.h"
 #include "empathy-time.h"
-#include "empathy-debug.h"
 #include "empathy-utils.h"
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
-		       EMPATHY_TYPE_LOG_MANAGER, EmpathyLogManagerPriv))
-
-#define DEBUG_DOMAIN "LogManager"
+#define DEBUG_FLAG EMPATHY_DEBUG_OTHER
+#include "empathy-debug.h"
 
 #define LOG_DIR_CREATE_MODE       (S_IRUSR | S_IWUSR | S_IXUSR)
 #define LOG_FILE_CREATE_MODE      (S_IRUSR | S_IWUSR)
@@ -53,12 +50,11 @@
 #define LOG_FOOTER \
     "</log>\n"
 
-struct _EmpathyLogManagerPriv {
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyLogManager)
+typedef struct {
 	gchar *basedir;
-};
+} EmpathyLogManagerPriv;
 
-static void                 empathy_log_manager_class_init         (EmpathyLogManagerClass *klass);
-static void                 empathy_log_manager_init               (EmpathyLogManager      *manager);
 static void                 log_manager_finalize                   (GObject                *object);
 static const gchar *        log_manager_get_basedir                (EmpathyLogManager      *manager);
 static GList *              log_manager_get_all_files              (EmpathyLogManager      *manager,
@@ -100,6 +96,10 @@ empathy_log_manager_class_init (EmpathyLogManagerClass *klass)
 static void
 empathy_log_manager_init (EmpathyLogManager *manager)
 {
+	EmpathyLogManagerPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (manager,
+		EMPATHY_TYPE_LOG_MANAGER, EmpathyLogManagerPriv);
+
+	manager->priv = priv;
 }
 
 static void
@@ -146,7 +146,7 @@ empathy_log_manager_add_message (EmpathyLogManager *manager,
 	gchar         *timestamp;
 	gchar         *contact_name;
 	gchar         *contact_id;
-	EmpathyMessageType msg_type;
+	TpChannelTextMessageType msg_type;
 
 	g_return_if_fail (EMPATHY_IS_LOG_MANAGER (manager));
 	g_return_if_fail (chat_id != NULL);
@@ -155,7 +155,7 @@ empathy_log_manager_add_message (EmpathyLogManager *manager,
 	sender = empathy_message_get_sender (message);
 	account = empathy_contact_get_account (sender);
 	body_str = empathy_message_get_body (message);
-	msg_type = empathy_message_get_type (message);
+	msg_type = empathy_message_get_tptype (message);
 
 	if (G_STR_EMPTY (body_str)) {
 		return;
@@ -164,14 +164,13 @@ empathy_log_manager_add_message (EmpathyLogManager *manager,
 	filename = log_manager_get_filename (manager, account, chat_id, chatroom);
 	basedir = g_path_get_dirname (filename);
 	if (!g_file_test (basedir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
-		empathy_debug (DEBUG_DOMAIN, "Creating directory:'%s'", basedir);
+		DEBUG ("Creating directory:'%s'", basedir);
 
 		g_mkdir_with_parents (basedir, LOG_DIR_CREATE_MODE);
 	}
 	g_free (basedir);
 
-	empathy_debug (DEBUG_DOMAIN, "Adding message: '%s' to file: '%s'",
-		      body_str, filename);
+	DEBUG ("Adding message: '%s' to file: '%s'", body_str, filename);
 
 	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
 		file = g_fopen (filename, "w+");
@@ -255,12 +254,12 @@ empathy_log_manager_get_dates (EmpathyLogManager *manager,
 	directory = log_manager_get_dir (manager, account, chat_id, chatroom);
 	dir = g_dir_open (directory, 0, NULL);
 	if (!dir) {
-		empathy_debug (DEBUG_DOMAIN, "Could not open directory:'%s'", directory);
+		DEBUG ("Could not open directory:'%s'", directory);
 		g_free (directory);
 		return NULL;
 	}
 
-	empathy_debug (DEBUG_DOMAIN, "Collating a list of dates in:'%s'", directory);
+	DEBUG ("Collating a list of dates in:'%s'", directory);
 
 	while ((filename = g_dir_read_name (dir)) != NULL) {
 		if (!g_str_has_suffix (filename, LOG_FILENAME_SUFFIX)) {
@@ -283,7 +282,7 @@ empathy_log_manager_get_dates (EmpathyLogManager *manager,
 	g_free (directory);
 	g_dir_close (dir);
 
-	empathy_debug (DEBUG_DOMAIN, "Parsed %d dates", g_list_length (dates));
+	DEBUG ("Parsed %d dates", g_list_length (dates));
 
 	return dates;
 }
@@ -303,10 +302,10 @@ empathy_log_manager_get_messages_for_file (EmpathyLogManager *manager,
 	g_return_val_if_fail (EMPATHY_IS_LOG_MANAGER (manager), NULL);
 	g_return_val_if_fail (filename != NULL, NULL);
 
-	empathy_debug (DEBUG_DOMAIN, "Attempting to parse filename:'%s'...", filename);
+	DEBUG ("Attempting to parse filename:'%s'...", filename);
 
 	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		empathy_debug (DEBUG_DOMAIN, "Filename:'%s' does not exist", filename);
+		DEBUG ("Filename:'%s' does not exist", filename);
 		return NULL;
 	}
 
@@ -348,7 +347,7 @@ empathy_log_manager_get_messages_for_file (EmpathyLogManager *manager,
 		gchar              *is_user_str;
 		gboolean            is_user = FALSE;
 		gchar              *msg_type_str;
-		EmpathyMessageType  msg_type = EMPATHY_MESSAGE_TYPE_NORMAL;
+		TpChannelTextMessageType msg_type = TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL;
 
 		if (strcmp (node->name, "message") != 0) {
 			continue;
@@ -384,7 +383,7 @@ empathy_log_manager_get_messages_for_file (EmpathyLogManager *manager,
 		message = empathy_message_new (body);
 		empathy_message_set_sender (message, sender);
 		empathy_message_set_timestamp (message, t);
-		empathy_message_set_type (message, msg_type);
+		empathy_message_set_tptype (message, msg_type);
 
 		messages = g_list_append (messages, message);
 
@@ -397,7 +396,7 @@ empathy_log_manager_get_messages_for_file (EmpathyLogManager *manager,
 		xmlFree (msg_type_str);
 	}
 
-	empathy_debug (DEBUG_DOMAIN, "Parsed %d messages", g_list_length (messages));
+	DEBUG ("Parsed %d messages", g_list_length (messages));
 
 	xmlFreeDoc (doc);
 	xmlFreeParserCtxt (ctxt);
@@ -486,8 +485,7 @@ empathy_log_manager_search_new (EmpathyLogManager *manager,
 	text_casefold = g_utf8_casefold (text, -1);
 
 	files = log_manager_get_all_files (manager, NULL);
-	empathy_debug (DEBUG_DOMAIN, "Found %d log files in total",
-		      g_list_length (files));
+	DEBUG ("Found %d log files in total", g_list_length (files));
 
 	for (l = files; l; l = l->next) {
 		gchar       *filename;
@@ -516,9 +514,8 @@ empathy_log_manager_search_new (EmpathyLogManager *manager,
 
 			if (hit) {
 				hits = g_list_prepend (hits, hit);
-				empathy_debug (DEBUG_DOMAIN, 
-					      "Found text:'%s' in file:'%s' on date:'%s'...",
-					      text, hit->filename, hit->date);
+				DEBUG ("Found text:'%s' in file:'%s' on date:'%s'",
+					text, hit->filename, hit->date);
 			}
 		}
 
