@@ -31,16 +31,14 @@
 #include "empathy-contact-factory.h"
 #include "empathy-contact-list.h"
 #include "empathy-marshal.h"
-#include "empathy-debug.h"
 #include "empathy-time.h"
 #include "empathy-utils.h"
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
-		       EMPATHY_TYPE_TP_CHAT, EmpathyTpChatPriv))
+#define DEBUG_FLAG EMPATHY_DEBUG_TP | EMPATHY_DEBUG_CHAT
+#include "empathy-debug.h"
 
-#define DEBUG_DOMAIN "TpChat"
-
-struct _EmpathyTpChatPriv {
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyTpChat)
+typedef struct {
 	EmpathyContactFactory *factory;
 	EmpathyContact        *user;
 	EmpathyContact        *remote_contact;
@@ -49,13 +47,13 @@ struct _EmpathyTpChatPriv {
 	TpChannel             *channel;
 	gchar                 *id;
 	gboolean               acknowledge;
-	gboolean               had_pending_messages;
+	gboolean               listing_pending_messages;
 	GSList                *message_queue;
 	gboolean               had_properties_list;
 	GPtrArray             *properties;
 	gboolean               ready;
 	guint                  members_count;
-};
+} EmpathyTpChatPriv;
 
 typedef struct {
 	gchar          *name;
@@ -64,8 +62,6 @@ typedef struct {
 	GValue         *value;
 } TpChatProperty;
 
-static void empathy_tp_chat_class_init (EmpathyTpChatClass      *klass);
-static void empathy_tp_chat_init       (EmpathyTpChat           *chat);
 static void tp_chat_iface_init         (EmpathyContactListIface *iface);
 
 enum {
@@ -98,7 +94,7 @@ tp_chat_invalidated_cb (TpProxy       *proxy,
 			gchar         *message,
 			EmpathyTpChat *chat)
 {
-	empathy_debug (DEBUG_DOMAIN, "Channel invalidated: %s", message);
+	DEBUG ("Channel invalidated: %s", message);
 	g_signal_emit (chat, signals[DESTROY], 0);
 }
 
@@ -109,8 +105,7 @@ tp_chat_async_cb (TpChannel *proxy,
 		  GObject *weak_object)
 {
 	if (error) {
-		empathy_debug (DEBUG_DOMAIN, "Error %s: %s",
-			       user_data, error->message);
+		DEBUG ("Error %s: %s", (gchar*) user_data, error->message);
 	}
 }
 
@@ -275,7 +270,7 @@ tp_chat_build_message (EmpathyTpChat *chat,
 	}
 
 	message = empathy_message_new (message_body);
-	empathy_message_set_type (message, type);
+	empathy_message_set_tptype (message, type);
 	empathy_message_set_sender (message, sender);
 	empathy_message_set_receiver (message, priv->user);
 	empathy_message_set_timestamp (message, timestamp);
@@ -309,7 +304,7 @@ tp_chat_sender_ready_notify_cb (EmpathyContact *contact,
 			break;
 		}
 
-		empathy_debug (DEBUG_DOMAIN, "Queued message ready");
+		DEBUG ("Queued message ready");
 		g_signal_emit (chat, signals[MESSAGE_RECEIVED], 0, message);
 		priv->message_queue = g_slist_remove (priv->message_queue,
 						      message);
@@ -339,7 +334,7 @@ tp_chat_emit_or_queue_message (EmpathyTpChat  *chat,
 	EmpathyContactReady  ready;
 
 	if (priv->message_queue != NULL) {
-		empathy_debug (DEBUG_DOMAIN, "Message queue not empty");
+		DEBUG ("Message queue not empty");
 		priv->message_queue = g_slist_append (priv->message_queue,
 						      g_object_ref (message));
 		return;
@@ -348,12 +343,12 @@ tp_chat_emit_or_queue_message (EmpathyTpChat  *chat,
 	sender = empathy_message_get_sender (message);
 	ready = empathy_contact_get_ready (sender);
 	if (ready & EMPATHY_CONTACT_READY_NAME) {
-		empathy_debug (DEBUG_DOMAIN, "Message queue empty and sender ready");
+		DEBUG ("Message queue empty and sender ready");
 		g_signal_emit (chat, signals[MESSAGE_RECEIVED], 0, message);
 		return;
 	}
 
-	empathy_debug (DEBUG_DOMAIN, "Sender not ready");
+	DEBUG ("Sender not ready");
 	priv->message_queue = g_slist_append (priv->message_queue, 
 					      g_object_ref (message));
 	g_signal_connect (sender, "notify::ready",
@@ -375,11 +370,11 @@ tp_chat_received_cb (TpChannel   *channel,
 	EmpathyTpChatPriv *priv = GET_PRIV (chat);
 	EmpathyMessage    *message;
 
-	if (!priv->had_pending_messages) {
+	if (priv->listing_pending_messages) {
 		return;
 	}
  
- 	empathy_debug (DEBUG_DOMAIN, "Message received: %s", message_body);
+ 	DEBUG ("Message received: %s", message_body);
 
 	message = tp_chat_build_message (EMPATHY_TP_CHAT (chat),
 					 message_type,
@@ -416,7 +411,7 @@ tp_chat_sent_cb (TpChannel   *channel,
 {
 	EmpathyMessage *message;
 
-	empathy_debug (DEBUG_DOMAIN, "Message sent: %s", message_body);
+	DEBUG ("Message sent: %s", message_body);
 
 	message = tp_chat_build_message (EMPATHY_TP_CHAT (chat),
 					 message_type,
@@ -439,8 +434,7 @@ tp_chat_send_error_cb (TpChannel   *channel,
 {
 	EmpathyMessage *message;
 
-	empathy_debug (DEBUG_DOMAIN, "Message sent error: %s (%d)",
-		       message_body, error_code);
+	DEBUG ("Message sent error: %s (%d)", message_body, error_code);
 
 	message = tp_chat_build_message (EMPATHY_TP_CHAT (chat),
 					 message_type,
@@ -466,9 +460,8 @@ tp_chat_state_changed_cb (TpChannel *channel,
 							   priv->account,
 							   handle);
 
-	empathy_debug (DEBUG_DOMAIN, "Chat state changed for %s (%d): %d",
-		      empathy_contact_get_name (contact),
-		      handle, state);
+	DEBUG ("Chat state changed for %s (%d): %d",
+		empathy_contact_get_name (contact), handle, state);
 
 	g_signal_emit (chat, signals[CHAT_STATE_CHANGED], 0, contact, state);
 	g_object_unref (contact);
@@ -485,11 +478,10 @@ tp_chat_list_pending_messages_cb (TpChannel       *channel,
 	guint              i;
 	GArray            *message_ids = NULL;
 
-	priv->had_pending_messages = TRUE;
+	priv->listing_pending_messages = FALSE;
 
 	if (error) {
-		empathy_debug (DEBUG_DOMAIN, "Error listing pending messages: %s",
-			       error->message);
+		DEBUG ("Error listing pending messages: %s", error->message);
 		return;
 	}
 
@@ -517,7 +509,7 @@ tp_chat_list_pending_messages_cb (TpChannel       *channel,
 		message_flags = g_value_get_uint (g_value_array_get_nth (message_struct, 4));
 		message_body = g_value_get_string (g_value_array_get_nth (message_struct, 5));
 
-		empathy_debug (DEBUG_DOMAIN, "Message pending: %s", message_body);
+		DEBUG ("Message pending: %s", message_body);
 
 		if (message_ids) {
 			g_array_append_val (message_ids, message_id);
@@ -572,9 +564,8 @@ tp_chat_property_flags_changed_cb (TpProxy         *proxy,
 			property = g_ptr_array_index (priv->properties, j);
 			if (property->id == id) {
 				property->flags = flags;
-				empathy_debug (DEBUG_DOMAIN,
-					       "property %s flags changed: %d",
-					       property->name, property->flags);
+				DEBUG ("property %s flags changed: %d",
+					property->name, property->flags);
 				break;
 			}
 		}
@@ -613,8 +604,7 @@ tp_chat_properties_changed_cb (TpProxy         *proxy,
 					property->value = tp_g_value_slice_dup (src_value);
 				}
 
-				empathy_debug (DEBUG_DOMAIN, "property %s changed",
-					       property->name);
+				DEBUG ("property %s changed", property->name);
 				g_signal_emit (chat, signals[PROPERTY_CHANGED], 0,
 					       property->name, property->value);
 				break;
@@ -631,8 +621,7 @@ tp_chat_get_properties_cb (TpProxy         *proxy,
 			   GObject         *chat)
 {
 	if (error) {
-		empathy_debug (DEBUG_DOMAIN, "Error getting properties: %s",
-			       error->message);
+		DEBUG ("Error getting properties: %s", error->message);
 		return;
 	}
 
@@ -653,8 +642,7 @@ tp_chat_list_properties_cb (TpProxy         *proxy,
 	priv->had_properties_list = TRUE;
 
 	if (error) {
-		empathy_debug (DEBUG_DOMAIN, "Error listing properties: %s",
-			       error->message);
+		DEBUG ("Error listing properties: %s", error->message);
 		return;
 	}
 
@@ -670,8 +658,8 @@ tp_chat_list_properties_cb (TpProxy         *proxy,
 		property->name = g_value_dup_string (g_value_array_get_nth (prop_struct, 1));
 		property->flags = g_value_get_uint (g_value_array_get_nth (prop_struct, 3));
 
-		empathy_debug (DEBUG_DOMAIN, "Adding property name=%s id=%d flags=%d",
-			       property->name, property->id, property->flags);
+		DEBUG ("Adding property name=%s id=%d flags=%d",
+			property->name, property->id, property->flags);
 		g_ptr_array_add (priv->properties, property);
 		if (property->flags & TP_PROPERTY_FLAG_READ) {
 			g_array_append_val (ids, property->id);
@@ -722,7 +710,7 @@ empathy_tp_chat_set_property (EmpathyTpChat *chat,
 			properties = g_ptr_array_sized_new (1);
 			g_ptr_array_add (properties, prop);
 
-			empathy_debug (DEBUG_DOMAIN, "Set property %s", name);
+			DEBUG ("Set property %s", name);
 			tp_cli_properties_interface_call_set_properties (priv->channel, -1,
 									 properties,
 									 (tp_cli_properties_interface_callback_for_set_properties)
@@ -745,7 +733,7 @@ tp_chat_channel_ready_cb (EmpathyTpChat *chat)
 	TpConnection      *connection;
 	guint              handle, handle_type;
 
-	empathy_debug (DEBUG_DOMAIN, "Channel ready");
+	DEBUG ("Channel ready");
 
 	g_object_get (priv->channel,
 		      "connection", &connection,
@@ -808,6 +796,7 @@ tp_chat_channel_ready_cb (EmpathyTpChat *chat)
 									       G_OBJECT (chat), NULL);
 	}
 
+	priv->listing_pending_messages = TRUE;
 	tp_cli_channel_type_text_call_list_pending_messages (priv->channel, -1,
 							     FALSE,
 							     tp_chat_list_pending_messages_cb,
@@ -845,8 +834,10 @@ tp_chat_finalize (GObject *object)
 	EmpathyTpChatPriv *priv = GET_PRIV (object);
 	guint              i;
 
+	DEBUG ("Finalize: %p", object);
+
 	if (priv->acknowledge && priv->channel) {
-		empathy_debug (DEBUG_DOMAIN, "Closing channel...");
+		DEBUG ("Closing channel...");
 		tp_cli_channel_call_close (priv->channel, -1,
 					   tp_chat_async_cb,
 					   "closing channel", NULL,
@@ -886,6 +877,19 @@ tp_chat_finalize (GObject *object)
 	g_object_unref (priv->account);
 	g_free (priv->id);
 
+	if (priv->message_queue) {
+		EmpathyMessage *message;
+		EmpathyContact *contact;
+
+		message = priv->message_queue->data;
+		contact = empathy_message_get_sender (message);
+		g_signal_handlers_disconnect_by_func (contact,
+						      tp_chat_sender_ready_notify_cb,
+						      object);
+	}
+	g_slist_foreach (priv->message_queue, (GFunc) g_object_unref, NULL);
+	g_slist_free (priv->message_queue);
+
 	G_OBJECT_CLASS (empathy_tp_chat_parent_class)->finalize (object);
 }
 
@@ -993,8 +997,7 @@ empathy_tp_chat_class_init (EmpathyTpChatClass *klass)
 							       "acknowledge messages",
 							       "Wheter or not received messages should be acknowledged",
 							       FALSE,
-							       G_PARAM_READWRITE |
-							       G_PARAM_CONSTRUCT));
+							       G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_REMOTE_CONTACT,
@@ -1068,6 +1071,10 @@ empathy_tp_chat_class_init (EmpathyTpChatClass *klass)
 static void
 empathy_tp_chat_init (EmpathyTpChat *chat)
 {
+	EmpathyTpChatPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (chat,
+		EMPATHY_TYPE_TP_CHAT, EmpathyTpChatPriv);
+
+	chat->priv = priv;
 }
 
 static void
@@ -1079,12 +1086,10 @@ tp_chat_iface_init (EmpathyContactListIface *iface)
 }
 
 EmpathyTpChat *
-empathy_tp_chat_new (TpChannel *channel,
-		     gboolean   acknowledge)
+empathy_tp_chat_new (TpChannel *channel)
 {
 	return g_object_new (EMPATHY_TYPE_TP_CHAT, 
 			     "channel", channel,
-			     "acknowledge", acknowledge,
 			     NULL);
 }
 
@@ -1119,6 +1124,16 @@ empathy_tp_chat_get_account (EmpathyTpChat *chat)
 	return priv->account;
 }
 
+TpChannel *
+empathy_tp_chat_get_channel (EmpathyTpChat *chat)
+{
+	EmpathyTpChatPriv *priv = GET_PRIV (chat);
+
+	g_return_val_if_fail (EMPATHY_IS_TP_CHAT (chat), NULL);
+
+	return priv->channel;
+}
+
 gboolean
 empathy_tp_chat_is_ready (EmpathyTpChat *chat)
 {
@@ -1159,6 +1174,11 @@ empathy_tp_chat_emit_pendings (EmpathyTpChat *chat)
 	g_return_if_fail (EMPATHY_IS_TP_CHAT (chat));
 	g_return_if_fail (priv->ready);
 
+	if (priv->listing_pending_messages) {
+		return;
+	}
+
+	priv->listing_pending_messages = TRUE;
 	tp_cli_channel_type_text_call_list_pending_messages (priv->channel, -1,
 							     FALSE,
 							     tp_chat_list_pending_messages_cb,
@@ -1170,18 +1190,18 @@ void
 empathy_tp_chat_send (EmpathyTpChat *chat,
 		      EmpathyMessage *message)
 {
-	EmpathyTpChatPriv  *priv = GET_PRIV (chat);
-	const gchar        *message_body;
-	EmpathyMessageType  message_type;
+	EmpathyTpChatPriv        *priv = GET_PRIV (chat);
+	const gchar              *message_body;
+	TpChannelTextMessageType  message_type;
 
 	g_return_if_fail (EMPATHY_IS_TP_CHAT (chat));
 	g_return_if_fail (EMPATHY_IS_MESSAGE (message));
 	g_return_if_fail (priv->ready);
 
 	message_body = empathy_message_get_body (message);
-	message_type = empathy_message_get_type (message);
+	message_type = empathy_message_get_tptype (message);
 
-	empathy_debug (DEBUG_DOMAIN, "Sending message: %s", message_body);
+	DEBUG ("Sending message: %s", message_body);
 	tp_cli_channel_type_text_call_send (priv->channel, -1,
 					    message_type,
 					    message_body,
@@ -1199,7 +1219,7 @@ empathy_tp_chat_set_state (EmpathyTpChat      *chat,
 	g_return_if_fail (EMPATHY_IS_TP_CHAT (chat));
 	g_return_if_fail (priv->ready);
 
-	empathy_debug (DEBUG_DOMAIN, "Set state: %d", state);
+	DEBUG ("Set state: %d", state);
 	tp_cli_channel_interface_chat_state_call_set_chat_state (priv->channel, -1,
 								 state,
 								 tp_chat_async_cb,
