@@ -37,13 +37,13 @@
 #include <telepathy-glib/channel.h>
 #include <telepathy-glib/dbus.h>
 
-#include "empathy-debug.h"
 #include "empathy-utils.h"
 #include "empathy-contact-factory.h"
 #include "empathy-contact-manager.h"
 #include "empathy-tp-group.h"
 
-#define DEBUG_DOMAIN "Utils"
+#define DEBUG_FLAG EMPATHY_DEBUG_OTHER
+#include "empathy-debug.h"
 
 static void regex_init (void);
 
@@ -58,6 +58,7 @@ empathy_substring (const gchar *str,
 /*
  * Regular Expression code to match urls.
  */
+#define APTCHARS  "-A-Za-z0-9,-."
 #define USERCHARS "-A-Za-z0-9"
 #define PASSCHARS "-A-Za-z0-9,?;.:/!%$^*&~\"#'"
 #define HOSTCHARS "-A-Za-z0-9_"
@@ -91,6 +92,10 @@ regex_init (void)
 				"(www|ftp)[" HOSTCHARS "]*\\.[" HOSTCHARS ".]+"
 				"(:[0-9]+)?(" URLPATH ")?";
 			break;
+		case EMPATHY_REGEX_APT:
+			expression =
+				"apt://[" APTCHARS "]*";
+			break;
 		case EMPATHY_REGEX_EMAIL:
 			expression =
 				"(mailto:)?[a-z0-9][a-z0-9.-]*@[a-z0-9]"
@@ -146,9 +151,7 @@ empathy_regex_match (EmpathyRegExType  type,
 	}
 
 	if (type != EMPATHY_REGEX_ALL) {
-		empathy_debug (DEBUG_DOMAIN,
-			      "Found %d matches for regex type:%d",
-			      num_matches, type);
+		DEBUG ("Found %d matches for regex type:%d", num_matches, type);
 		return num_matches;
 	}
 
@@ -170,9 +173,7 @@ empathy_regex_match (EmpathyRegExType  type,
 		}
 	}
 
-	empathy_debug (DEBUG_DOMAIN,
-		      "Found %d matches for ALL regex types",
-		      num_matches);
+	DEBUG ("Found %d matches for ALL regex types", num_matches);
 
 	return num_matches;
 }
@@ -217,7 +218,7 @@ empathy_xml_validate (xmlDoc      *doc,
 		g_free (path);
 		path = g_build_filename (DATADIR, "empathy", dtd_filename, NULL);
 	}
-	empathy_debug (DEBUG_DOMAIN, "Loading dtd file %s", path);
+	DEBUG ("Loading dtd file %s", path);
 
 	/* The list of valid chars is taken from libxml. */
 	escaped = xmlURIEscapeStr (path, ":@&=+$,/?;");
@@ -340,7 +341,6 @@ empathy_mission_control_new (void)
 void
 empathy_call_with_contact (EmpathyContact *contact)
 {
-#ifdef HAVE_VOIP
 	MissionControl        *mc;
 	McAccount             *account;
 	TpConnection          *connection;
@@ -369,9 +369,8 @@ empathy_call_with_contact (EmpathyContact *contact)
 						    &object_path,
 						    &error,
 						    NULL)) {
-		empathy_debug (DEBUG_DOMAIN, 
-			      "Couldn't request channel: %s",
-			      error ? error->message : "No error given");
+		DEBUG ("Couldn't request channel: %s",
+			error ? error->message : "No error given");
 		g_clear_error (&error);
 		g_object_unref (connection);
 		return;
@@ -399,13 +398,11 @@ empathy_call_with_contact (EmpathyContact *contact)
 	g_object_unref (connection);
 	g_object_unref (channel);
 	g_free (object_path);
-#endif
 }
 
 void
 empathy_call_with_contact_id (McAccount *account, const gchar *contact_id)
 {
-#ifdef HAVE_VOIP
 	EmpathyContactFactory *factory;
 	EmpathyContact        *contact;
 
@@ -417,7 +414,6 @@ empathy_call_with_contact_id (McAccount *account, const gchar *contact_id)
 
 	g_object_unref (contact);
 	g_object_unref (factory);
-#endif
 }
 
 void
@@ -561,7 +557,7 @@ static void
 run_until_ready_cb (RunUntilReadyData *data)
 {
 	if (!data->func || data->func (data->object, data->user_data)) {
-		empathy_debug (DEBUG_DOMAIN, "Object %p is ready", data->object);
+		DEBUG ("Object %p is ready", data->object);
 		g_main_loop_quit (data->loop);
 	}
 }
@@ -594,8 +590,7 @@ empathy_run_until_ready_full (gpointer                  object,
 		return;
 	}
 
-	empathy_debug (DEBUG_DOMAIN, "Starting run until ready for object %p",
-		       object);
+	DEBUG ("Starting run until ready for object %p", object);
 
 	data.func = func;
 	data.user_data = user_data;
