@@ -34,12 +34,12 @@
 #include <glade/glade.h>
 #include <glib/gi18n.h>
 
+#include <telepathy-glib/util.h>
 #include <libmissioncontrol/mission-control.h>
 
 #include <libempathy/empathy-contact-factory.h>
 #include <libempathy/empathy-contact.h>
 #include <libempathy/empathy-message.h>
-#include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-utils.h>
 
 #include <libempathy-gtk/empathy-images.h>
@@ -52,11 +52,11 @@
 #include "empathy-chat-window.h"
 #include "empathy-about-dialog.h"
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EMPATHY_TYPE_CHAT_WINDOW, EmpathyChatWindowPriv))
+#define DEBUG_FLAG EMPATHY_DEBUG_CHAT
+#include <libempathy/empathy-debug.h>
 
-#define DEBUG_DOMAIN "ChatWindow"
-
-struct _EmpathyChatWindowPriv {
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyChatWindow)
+typedef struct {
 	EmpathyChat *current_chat;
 	GList       *chats;
 	GList       *chats_new_msg;
@@ -85,11 +85,7 @@ struct _EmpathyChatWindowPriv {
 	
 	GtkWidget   *menu_help_contents;
 	GtkWidget   *menu_help_about;
-};
-
-static void       empathy_chat_window_class_init (EmpathyChatWindowClass *klass);
-static void       empathy_chat_window_init       (EmpathyChatWindow      *window);
-static void       chat_window_finalize           (GObject                *object);
+} EmpathyChatWindowPriv;
 
 static GList *chat_windows = NULL;
 
@@ -300,7 +296,7 @@ chat_window_update (EmpathyChatWindow *window)
 	name = chat_window_get_chat_name (priv->current_chat);
 	n_chats = g_list_length (priv->chats);
 
-	empathy_debug (DEBUG_DOMAIN, "Update window");
+	DEBUG ("Update window");
 
 	/* Update menu */
 	gtk_widget_set_sensitive (priv->menu_tabs_next, !last_page);
@@ -354,8 +350,8 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 	subject = empathy_chat_get_subject (chat);
 	remote_contact = empathy_chat_get_remote_contact (chat);
 
-	empathy_debug (DEBUG_DOMAIN, "Updating chat tab, name=%s, subject=%s, "
-		       "remote_contact=%p", name, subject, remote_contact);
+	DEBUG ("Updating chat tab, name=%s, subject=%s, remote_contact=%p",
+		name, subject, remote_contact);
 
 	/* Update tab image */
 	if (g_list_find (priv->chats_new_msg, chat)) {
@@ -456,13 +452,29 @@ chat_window_insert_smiley_activate_cb (GtkWidget         *menuitem,
 				smiley, -1);
 }
 
+static void
+chat_window_conv_activate_cb (GtkWidget         *menuitem,
+			      EmpathyChatWindow *window)
+{
+	EmpathyChatWindowPriv *priv = GET_PRIV (window);
+	GtkWidget             *submenu = NULL;
+
+	submenu = empathy_chat_get_contact_menu (priv->current_chat);
+	if (submenu) {
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (priv->menu_conv_contact),
+					   submenu);
+		gtk_widget_show (priv->menu_conv_contact);
+		gtk_widget_show (submenu);
+	} else {
+		gtk_widget_hide (priv->menu_conv_contact);
+	}
+}
+
 static void
 chat_window_clear_activate_cb (GtkWidget        *menuitem,
 			       EmpathyChatWindow *window)
 {
-	EmpathyChatWindowPriv *priv;
-
-	priv = GET_PRIV (window);
+	EmpathyChatWindowPriv *priv = GET_PRIV (window);
 
 	empathy_chat_clear (priv->current_chat);
 }
@@ -470,17 +482,18 @@ chat_window_clear_activate_cb (GtkWidget        *menuitem,
 static const gchar *
 chat_get_window_id_for_geometry (EmpathyChat *chat)
 {
-	gboolean separate_windows;
+	const gchar *res = NULL;
+	gboolean     separate_windows;
 
 	empathy_conf_get_bool (empathy_conf_get (),
 			       EMPATHY_PREFS_UI_SEPARATE_CHAT_WINDOWS,
 			       &separate_windows);
 
 	if (separate_windows) {
-		return empathy_chat_get_id (chat);
-	} else {
-		return "chat-window";
+		res = empathy_chat_get_id (chat);
 	}
+
+	return res ? res : "chat-window";
 }
 
 static gboolean
@@ -693,21 +706,15 @@ chat_window_delete_event_cb (GtkWidget        *dialog,
 			     GdkEvent         *event,
 			     EmpathyChatWindow *window)
 {
-	EmpathyChatWindowPriv *priv;
-	GList                *list;
-	GList                *l;
+	EmpathyChatWindowPriv *priv = GET_PRIV (window);
 
-	priv = GET_PRIV (window);
+	DEBUG ("Delete event received");
 
-	empathy_debug (DEBUG_DOMAIN, "Delete event received");
-
-	list = g_list_copy (priv->chats);
-
-	for (l = list; l; l = l->next) {
-		empathy_chat_window_remove_chat (window, l->data);
+	g_object_ref (window);
+	while (priv->chats) {
+		empathy_chat_window_remove_chat (window, priv->chats->data);
 	}
-
-	g_list_free (list);
+	g_object_unref (window);
 
 	return TRUE;
 }
@@ -738,8 +745,7 @@ chat_window_set_urgency_hint (EmpathyChatWindow *window,
 
 	priv = GET_PRIV (window);
 
-	empathy_debug (DEBUG_DOMAIN, "Turning %s urgency hint",
-		       urgent ? "on" : "off");
+	DEBUG ("Turning %s urgency hint", urgent ? "on" : "off");
 	gtk_window_set_urgency_hint (GTK_WINDOW (priv->dialog), urgent);
 }
 
@@ -793,7 +799,7 @@ chat_window_detach_hook (GtkNotebook *source,
 	new_window = empathy_chat_window_new ();
 	priv = GET_PRIV (new_window);
 
-	empathy_debug (DEBUG_DOMAIN, "Detach hook called");
+	DEBUG ("Detach hook called");
 
 	empathy_chat_window_move_chat (window, new_window, chat);
 
@@ -813,7 +819,7 @@ chat_window_page_switched_cb (GtkNotebook      *notebook,
 	EmpathyChat           *chat;
 	GtkWidget            *child;
 
-	empathy_debug (DEBUG_DOMAIN, "Page switched");
+	DEBUG ("Page switched");
 
 	priv = GET_PRIV (window);
 
@@ -850,12 +856,12 @@ chat_window_page_added_cb (GtkNotebook      *notebook,
 	 * it, so we return here and in "page-added".
 	 */
 	if (priv->dnd_same_window) {
-		empathy_debug (DEBUG_DOMAIN, "Page added (back to the same window)");
+		DEBUG ("Page added (back to the same window)");
 		priv->dnd_same_window = FALSE;
 		return;
 	}
 
-	empathy_debug (DEBUG_DOMAIN, "Page added");
+	DEBUG ("Page added");
 
 	/* Get chat object */
 	chat = EMPATHY_CHAT (child);
@@ -895,11 +901,11 @@ chat_window_page_removed_cb (GtkNotebook      *notebook,
 	 * it, so we return here and in "page-added".
 	 */
 	if (priv->dnd_same_window) {
-		empathy_debug (DEBUG_DOMAIN, "Page removed (and will be readded to same window)");
+		DEBUG ("Page removed (and will be readded to same window)");
 		return;
 	}
 
-	empathy_debug (DEBUG_DOMAIN, "Page removed");
+	DEBUG ("Page removed");
 
 	/* Get chat object */
 	chat = EMPATHY_CHAT (child);
@@ -931,7 +937,7 @@ chat_window_focus_in_event_cb (GtkWidget        *widget,
 {
 	EmpathyChatWindowPriv *priv;
 
-	empathy_debug (DEBUG_DOMAIN, "Focus in event, updating title");
+	DEBUG ("Focus in event, updating title");
 
 	priv = GET_PRIV (window);
 
@@ -964,7 +970,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 
 		id = (const gchar*) selection->data;
 
-		empathy_debug (DEBUG_DOMAIN, "DND contact from roster with id:'%s'", id);
+		DEBUG ("DND contact from roster with id:'%s'", id);
 		
 		strv = g_strsplit (id, "/", 2);
 		account = mc_account_lookup (strv[0]);
@@ -1005,7 +1011,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 		EmpathyChat        **chat;
 		EmpathyChatWindow   *old_window = NULL;
 
-		empathy_debug (DEBUG_DOMAIN, "DND tab");
+		DEBUG ("DND tab");
 
 		chat = (void*) selection->data;
 		old_window = chat_window_find_chat (*chat);
@@ -1016,7 +1022,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 			priv = GET_PRIV (window);
 
 			if (old_window == window) {
-				empathy_debug (DEBUG_DOMAIN, "DND tab (within same window)");
+				DEBUG ("DND tab (within same window)");
 				priv->dnd_same_window = TRUE;
 				gtk_drag_finish (context, TRUE, FALSE, time);
 				return;
@@ -1032,7 +1038,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 		 */
 		gtk_drag_finish (context, TRUE, FALSE, time);
 	} else {
-		empathy_debug (DEBUG_DOMAIN, "DND from unknown source");
+		DEBUG ("DND from unknown source");
 		gtk_drag_finish (context, FALSE, FALSE, time);
 	}
 }
@@ -1046,7 +1052,7 @@ chat_window_finalize (GObject *object)
 	window = EMPATHY_CHAT_WINDOW (object);
 	priv = GET_PRIV (window);
 
-	empathy_debug (DEBUG_DOMAIN, "Finalized: %p", object);
+	DEBUG ("Finalized: %p", object);
 
 	if (priv->save_geometry_id != 0) {
 		g_source_remove (priv->save_geometry_id);
@@ -1083,18 +1089,18 @@ empathy_chat_window_class_init (EmpathyChatWindowClass *klass)
 static void
 empathy_chat_window_init (EmpathyChatWindow *window)
 {
-	EmpathyChatWindowPriv *priv;
-	GladeXML             *glade;
-	GtkAccelGroup        *accel_group;
-	GClosure             *closure;
-	GtkWidget            *menu_conv;
-	GtkWidget            *menu;
-	gint                  i;
-	GtkWidget            *chat_vbox;
-	gchar                *filename;
-
-	priv = GET_PRIV (window);
+	GladeXML              *glade;
+	GtkAccelGroup         *accel_group;
+	GClosure              *closure;
+	GtkWidget             *menu_conv;
+	GtkWidget             *menu;
+	gint                   i;
+	GtkWidget             *chat_vbox;
+	gchar                 *filename;
+	EmpathyChatWindowPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (window,
+		EMPATHY_TYPE_CHAT_WINDOW, EmpathyChatWindowPriv);
 
+	window->priv = priv;
 	filename = empathy_file_lookup ("empathy-chat-window.glade", "src");
 	glade = empathy_glade_get_file (filename,
 				       "chat_window",
@@ -1122,6 +1128,7 @@ empathy_chat_window_init (EmpathyChatWindow *window)
 	empathy_glade_connect (glade,
 			      window,
 			      "chat_window", "configure-event", chat_window_configure_event_cb,
+			      "menu_conv", "activate", chat_window_conv_activate_cb,
 			      "menu_conv_clear", "activate", chat_window_clear_activate_cb,
 			      "menu_conv_close", "activate", chat_window_close_activate_cb,
 			      "menu_edit", "activate", chat_window_edit_activate_cb,
@@ -1328,9 +1335,7 @@ empathy_chat_window_add_chat (EmpathyChatWindow *window,
 	gtk_notebook_set_tab_label_packing (GTK_NOTEBOOK (priv->notebook), child,
 					    TRUE, TRUE, GTK_PACK_START); 
 
-	empathy_debug (DEBUG_DOMAIN, 
-		      "Chat added (%d references)",
-		      G_OBJECT (chat)->ref_count);
+	DEBUG ("Chat added (%d references)", G_OBJECT (chat)->ref_count);
 }
 
 void
@@ -1361,9 +1366,7 @@ empathy_chat_window_remove_chat (EmpathyChatWindow *window,
 					  GTK_WIDGET (chat));
 	gtk_notebook_remove_page (GTK_NOTEBOOK (priv->notebook), position);
 
-	empathy_debug (DEBUG_DOMAIN, 
-		      "Chat removed (%d references)", 
-		      G_OBJECT (chat)->ref_count - 1);
+	DEBUG ("Chat removed (%d references)", G_OBJECT (chat)->ref_count - 1);
 
 	g_object_unref (chat);
 }
@@ -1381,10 +1384,8 @@ empathy_chat_window_move_chat (EmpathyChatWindow *old_window,
 
 	widget = GTK_WIDGET (chat);
 
-	empathy_debug (DEBUG_DOMAIN,
-		      "Chat moving with widget:%p (%d references)", 
-		      widget,
-		      G_OBJECT (widget)->ref_count);
+	DEBUG ("Chat moving with widget:%p (%d references)", widget,
+		G_OBJECT (widget)->ref_count);
 
 	/* We reference here to make sure we don't loose the widget
 	 * and the EmpathyChat object during the move.
@@ -1455,7 +1456,7 @@ empathy_chat_window_find_chat (McAccount   *account,
 			chat = ll->data;
 
 			if (empathy_account_equal (account, empathy_chat_get_account (chat)) &&
-			    strcmp (id, empathy_chat_get_id (chat)) == 0) {
+			    !tp_strdiff (id, empathy_chat_get_id (chat))) {
 				return chat;
 			}
 		}
